@@ -13,7 +13,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
-# Copyright (C) 2011-2019 Dominik Kriegner <dominik.kriegner@gmail.com>
+# Copyright (C) 2011-2023 Dominik Kriegner <dominik.kriegner@gmail.com>
 
 import numpy
 
@@ -111,8 +111,8 @@ def get_qz_scan(qpos, intensity, cutpos, npoints, intrange, **kwargs):
 
     Examples
     --------
-    >>> qzcut, qzcut_int, mask = get_qz_scan([qy, qz], inten, 3.0, 200,
-                                             intrange=0.3)
+    >>> qzcut, qzcut_int, mask = get_qz_scan([qy, qz], inten, 3.0, 200,\
+    ... intrange=0.3)  # doctest: +SKIP
     """
     intdir = kwargs.get('intdir', 'q')
     lam = kwargs.get('wl', config.WAVELENGTH)
@@ -131,18 +131,20 @@ def get_qz_scan(qpos, intensity, cutpos, npoints, intrange, **kwargs):
         qperp = numpy.sqrt((lqpos[0]-lcut[0])**2 + (lqpos[1]-lcut[1])**2)
         ret = _get_cut(lqpos[2], qperp, intensity, intrange/2., npoints)
     elif intdir == 'omega':
-        om, chi, phi, tt = hxrd.Q2Ang(*lqpos, trans=False, geometry='realTilt')
+        om, _, _, tt = hxrd.Q2Ang(*lqpos, trans=False, geometry='realTilt')
         q = 4 * numpy.pi / lam * numpy.sin(numpy.radians(tt/2))
         ocut = numpy.degrees(numpy.arcsin(lcut[1]/q)) + tt / 2
         qzpos = q * numpy.cos(numpy.radians(ocut - tt/2))
         ret = _get_cut(qzpos, om-ocut, intensity, intrange/2., npoints)
     elif intdir == '2theta':
-        om, chi, phi, tt = hxrd.Q2Ang(*lqpos, trans=False, geometry='realTilt')
+        om, _, _, tt = hxrd.Q2Ang(*lqpos, trans=False, geometry='realTilt')
         q = 4 * numpy.pi / lam * numpy.sin(numpy.radians(tt/2))
         ttcut = 2 * (om - numpy.degrees(numpy.arcsin(lcut[1]/q)))
         qzpos = 4 * numpy.pi / lam * numpy.sin(numpy.radians(ttcut/2)) *\
             numpy.cos(numpy.radians(om - ttcut/2))
         ret = _get_cut(qzpos, tt-ttcut, intensity, intrange/2., npoints)
+    else:
+        raise ValueError("invalid option for argument 'intdir'")
 
     return ret
 
@@ -197,8 +199,8 @@ def get_qy_scan(qpos, intensity, cutpos, npoints, intrange, **kwargs):
 
     Examples
     --------
-    >>> qycut, qycut_int, mask = get_qy_scan([qy, qz], inten, 5.0, 250,
-                                             intrange=0.02, intdir='2theta')
+    >>> qycut, qycut_int, mask = get_qy_scan([qy, qz], inten, 5.0, 250, \
+    ... intrange=0.02, intdir='2theta')  # doctest: +SKIP
     """
     intdir = kwargs.get('intdir', 'q')
     lam = kwargs.get('wl', config.WAVELENGTH)
@@ -217,14 +219,14 @@ def get_qy_scan(qpos, intensity, cutpos, npoints, intrange, **kwargs):
         qperp = numpy.sqrt((lqpos[0]-lcut[0])**2 + (lqpos[2]-lcut[1])**2)
         ret = _get_cut(lqpos[1], qperp, intensity, intrange/2., npoints)
     elif intdir == 'omega':
-        om, chi, phi, tt = hxrd.Q2Ang(*lqpos, trans=False, geometry='real')
+        om, _, _, tt = hxrd.Q2Ang(*lqpos, trans=False, geometry='real')
         q = 4 * numpy.pi / lam * numpy.sin(numpy.radians(tt/2))
         ocut = tt / 2 + (numpy.sign(lqpos[1].ravel()) *
                          numpy.degrees(numpy.arccos(lcut[1]/q)))
         qypos = q * numpy.sin(numpy.radians(ocut - tt/2))
         ret = _get_cut(qypos, om-ocut, intensity, intrange/2., npoints)
     elif intdir == '2theta':
-        om, chi, phi, tt = hxrd.Q2Ang(*lqpos, trans=False, geometry='real')
+        om, _, _, tt = hxrd.Q2Ang(*lqpos, trans=False, geometry='real')
         ttcut = (om - numpy.degrees(numpy.arcsin(numpy.sin(numpy.radians(om)) -
                                     lcut[1]*lam/(2*numpy.pi)))) % 360
         ttcut2 = (om +
@@ -236,6 +238,8 @@ def get_qy_scan(qpos, intensity, cutpos, npoints, intrange, **kwargs):
         q = 4 * numpy.pi / lam * numpy.sin(numpy.radians(ttcut/2))
         qypos = q * numpy.sin(numpy.radians(om - ttcut/2))
         ret = _get_cut(qypos, tt-ttcut, intensity, intrange/2., npoints)
+    else:
+        raise ValueError("invalid option for argument 'intdir'")
 
     return ret
 
@@ -287,8 +291,8 @@ def get_qx_scan(qpos, intensity, cutpos, npoints, intrange, **kwargs):
 
     Examples
     --------
-    >>> qxcut, qxcut_int, mask = get_qx_scan([qx, qy, qz], inten, [0, 2.0],
-                                             250, intrange=0.01)
+    >>> qxcut, qxcut_int, mask = get_qx_scan([qx, qy, qz], inten, [0, 2.0], \
+    ... 250, intrange=0.01)  # doctest: +SKIP
     """
     intdir = kwargs.get('intdir', 'q')
     lam = kwargs.get('wl', config.WAVELENGTH)
@@ -300,16 +304,18 @@ def get_qx_scan(qpos, intensity, cutpos, npoints, intrange, **kwargs):
         ret = _get_cut(qpos[0], qperp, intensity, intrange/2., npoints)
     elif intdir == 'omega':
         # needs testing
-        om, chi, phi, tt = hxrd.Q2Ang(*qpos, trans=False, geometry='realTilt')
-        ocut, dmy, dmy, ttcut = hxrd.Q2Ang(qpos[0], cutpos[0], cutpos[1],
-                                           trans=False, geometry='realTilt')
+        om, _, _, tt = hxrd.Q2Ang(*qpos, trans=False, geometry='realTilt')
+        ocut, _, _, ttcut = hxrd.Q2Ang(qpos[0], cutpos[0], cutpos[1],
+                                       trans=False, geometry='realTilt')
         ret = _get_cut(qpos[0], om-ocut, intensity, intrange/2., npoints)
     elif intdir == '2theta':
         # needs testing
-        om, chi, phi, tt = hxrd.Q2Ang(*qpos, trans=False, geometry='realTilt')
-        ocut, dmy, dmy, ttcut = hxrd.Q2Ang(qpos[0], cutpos[0], cutpos[1],
-                                           trans=False, geometry='realTilt')
+        om, _, _, tt = hxrd.Q2Ang(*qpos, trans=False, geometry='realTilt')
+        ocut, _, _, ttcut = hxrd.Q2Ang(qpos[0], cutpos[0], cutpos[1],
+                                       trans=False, geometry='realTilt')
         ret = _get_cut(qpos[0], tt-ttcut, intensity, intrange/2., npoints)
+    else:
+        raise ValueError("invalid option for argument 'intdir'")
 
     return ret
 
@@ -362,8 +368,8 @@ def get_omega_scan(qpos, intensity, cutpos, npoints, intrange, **kwargs):
 
     Examples
     --------
-    >>> omcut, omcut_int, mask = get_omega_scan([qy, qz], inten, [2.0, 5.0],
-                                                250, intrange=0.1)
+    >>> omcut, omcut_int, mask = get_omega_scan([qy, qz], inten, [2.0, 5.0], \
+    ... 250, intrange=0.1)  # doctest: +SKIP
     """
     intdir = kwargs.get('intdir', '2theta')
     lam = kwargs.get('wl', config.WAVELENGTH)
@@ -378,13 +384,15 @@ def get_omega_scan(qpos, intensity, cutpos, npoints, intrange, **kwargs):
         lcut = cutpos
 
     # make line cuts with selected integration direction
-    om, chi, phi, tt = hxrd.Q2Ang(*lqpos, trans=False, geometry='realTilt')
-    ocut, dmy, dmy, ttcut = hxrd.Q2Ang(*lcut, trans=False, geometry='realTilt')
+    om, _, _, tt = hxrd.Q2Ang(*lqpos, trans=False, geometry='realTilt')
+    _, _, _, ttcut = hxrd.Q2Ang(*lcut, trans=False, geometry='realTilt')
     if intdir == '2theta':
         ret = _get_cut(om, tt-ttcut, intensity, intrange/2., npoints)
     elif intdir == 'radial':
         ret = _get_cut(om-(tt-ttcut)/2, tt-ttcut, intensity, intrange/2.,
                        npoints)
+    else:
+        raise ValueError("invalid option for argument 'intdir'")
 
     return ret
 
@@ -437,8 +445,8 @@ def get_radial_scan(qpos, intensity, cutpos, npoints, intrange, **kwargs):
 
     Examples
     --------
-    >>> ttcut, omtt_int, mask = get_radial_scan([qy, qz], inten, [2.0, 5.0],
-                                                250, intrange=0.1)
+    >>> ttcut, omtt_int, mask = get_radial_scan([qy, qz], inten, [2.0, 5.0], \
+    ... 250, intrange=0.1)  # doctest: +SKIP
     """
     intdir = kwargs.get('intdir', 'omega')
     lam = kwargs.get('wl', config.WAVELENGTH)
@@ -453,8 +461,8 @@ def get_radial_scan(qpos, intensity, cutpos, npoints, intrange, **kwargs):
         lcut = cutpos
 
     # make line cuts with selected integration direction
-    om, chi, phi, tt = hxrd.Q2Ang(*lqpos, trans=False, geometry='realTilt')
-    ocut, dmy, dmy, ttcut = hxrd.Q2Ang(*lcut, trans=False, geometry='realTilt')
+    om, _, _, tt = hxrd.Q2Ang(*lqpos, trans=False, geometry='realTilt')
+    ocut, _, _, ttcut = hxrd.Q2Ang(*lcut, trans=False, geometry='realTilt')
     if intdir == 'omega':
         ret = _get_cut(tt, om-((tt-ttcut)/2+ocut), intensity, intrange/2.,
                        npoints)
@@ -462,6 +470,8 @@ def get_radial_scan(qpos, intensity, cutpos, npoints, intrange, **kwargs):
         offcut = ttcut/2 - ocut
         ret = _get_cut(tt-2*(tt/2-om-offcut), 2*(tt/2-om-offcut), intensity,
                        intrange/2., npoints)
+    else:
+        raise ValueError("invalid option for argument 'intdir'")
 
     return ret
 
@@ -514,8 +524,8 @@ def get_ttheta_scan(qpos, intensity, cutpos, npoints, intrange, **kwargs):
 
     Examples
     --------
-    >>> ttcut, tt_int, mask = get_ttheta_scan([qy, qz], inten, [2.0, 5.0],
-                                              250, intrange=0.1)
+    >>> ttcut, tt_int, mask = get_ttheta_scan([qy, qz], inten, [2.0, 5.0], \
+    ... 250, intrange=0.1)  # doctest: +SKIP
     """
     intdir = kwargs.get('intdir', 'omega')
     lam = kwargs.get('wl', config.WAVELENGTH)
@@ -530,13 +540,15 @@ def get_ttheta_scan(qpos, intensity, cutpos, npoints, intrange, **kwargs):
         lcut = cutpos
 
     # make line cuts with selected integration direction
-    om, chi, phi, tt = hxrd.Q2Ang(*lqpos, trans=False, geometry='realTilt')
-    ocut, dmy, dmy, ttcut = hxrd.Q2Ang(*lcut, trans=False, geometry='realTilt')
+    om, _, _, tt = hxrd.Q2Ang(*lqpos, trans=False, geometry='realTilt')
+    ocut, _, _, _ = hxrd.Q2Ang(*lcut, trans=False, geometry='realTilt')
     if intdir == 'omega':
         ret = _get_cut(tt, om-ocut, intensity, intrange/2., npoints)
     elif intdir == 'radial':
         ret = _get_cut(tt-2*(om-ocut), 2*(om-ocut), intensity,
                        intrange/2., npoints)
+    else:
+        raise ValueError("invalid option for argument 'intdir'")
 
     return ret
 
@@ -575,9 +587,9 @@ def get_arbitrary_line(qpos, intensity, point, vec, npoints, intrange):
 
     Examples
     --------
-    >>> qcut, qint, mask = get_arbitrary_line([qx, qy, qz], inten,
-                                              (1.1, 2.2, 0.0),
-                                              (1, 1, 1), 200, 0.1)
+    >>> qcut, qint, mask = get_arbitrary_line([qx, qy, qz], inten, \
+    ... (1.1, 2.2, 0.0), \
+    ... (1, 1, 1), 200, 0.1)  # doctest: +SKIP
     """
     # make all data 3D
     if len(qpos) == 2:
