@@ -16,12 +16,12 @@
 # Copyright (C) 2009-2010, 2013
 #               Eugen Wintersberger <eugen.wintersberger@desy.de>
 # Copyright (C) 2009 Mario Keplinger <mario.keplinger@jku.at>
-# Copyright (C) 2009-2021 Dominik Kriegner <dominik.kriegner@gmail.com>
+# Copyright (c) 2009-2021, 2023 Dominik Kriegner <dominik.kriegner@gmail.com>
 
 import numpy
 
 from . import cxrayutilities, exception, utilities
-from .gridder import Gridder, axis, delta, ones
+from .gridder import Gridder, GridderFlags, axis, delta, ones
 
 
 class Gridder2D(Gridder):
@@ -141,9 +141,9 @@ class Gridder2D(Gridder):
         data = self._prepare_array(data)
 
         if x.size != y.size or y.size != data.size:
-            raise exception.InputError("XU.%s: size of given datasets "
-                                       "(x, y, data) is not equal!"
-                                       % self.__class__.__name__)
+            raise exception.InputError(
+                f"XU.{self.__class__.__name__}: size of given datasets "
+                "(x, y, data) is not equal!")
 
         if not self.fixed_range:
             # assume that with setting keep_data the user wants to call the
@@ -168,7 +168,7 @@ class Gridder2D(Gridder):
         """
         x, y, data = self._checktransinput(x, y, data)
         # remove normalize flag for C-code
-        flags = utilities.set_bit(self.flags, 2)
+        flags = self.flags | GridderFlags.NO_NORMALIZATION
         cxrayutilities.gridder2d(x, y, data, self.nx, self.ny,
                                  self.xmin, self.xmax,
                                  self.ymin, self.ymax,
@@ -226,7 +226,7 @@ class FuzzyGridder2D(Gridder2D):
             wx = delta(self.xmin, self.xmax, self.nx) / 2.
             wy = delta(self.ymin, self.ymax, self.ny) / 2.
         # remove normalize flag for C-code
-        flags = utilities.set_bit(self.flags, 2)
+        flags = self.flags | GridderFlags.NO_NORMALIZATION
         cxrayutilities.fuzzygridder2d(x, y, data, self.nx, self.ny,
                                       self.xmin, self.xmax,
                                       self.ymin, self.ymax,
