@@ -16,12 +16,12 @@
 # Copyright (C) 2009-2010, 2013
 #               Eugen Wintersberger <eugen.wintersberger@desy.de>
 # Copyright (C) 2009 Mario Keplinger <mario.keplinger@jku.at>
-# Copyright (C) 2009-2019 Dominik Kriegner <dominik.kriegner@gmail.com>
+# Copyright (c) 2009-2019, 2023 Dominik Kriegner <dominik.kriegner@gmail.com>
 
 import numpy
 
 from . import cxrayutilities, exception, utilities
-from .gridder import Gridder, axis, delta, ones
+from .gridder import Gridder, GridderFlags, axis, delta, ones
 
 
 class Gridder3D(Gridder):
@@ -131,9 +131,9 @@ class Gridder3D(Gridder):
         data = self._prepare_array(data)
 
         if x.size != y.size or y.size != z.size or z.size != data.size:
-            raise exception.InputError("XU.%s: size of given datasets "
-                                       "(x, y, z, data) is not equal!"
-                                       % self.__class__.__name__)
+            raise exception.InputError(
+                f"XU.{self.__class__.__name__}: size of given datasets "
+                "(x, y, z, data) is not equal!")
 
         if not self.fixed_range:
             # assume that with setting keep_data the user wants to call the
@@ -165,7 +165,7 @@ class Gridder3D(Gridder):
         x, y, z, data = self._checktransinput(x, y, z, data)
 
         # remove normalize flag for C-code
-        flags = utilities.set_bit(self.flags, 2)
+        flags = self.flags | GridderFlags.NO_NORMALIZATION
         cxrayutilities.gridder3d(x, y, z, data, self.nx, self.ny, self.nz,
                                  self.xmin, self.xmax,
                                  self.ymin, self.ymax,
@@ -228,7 +228,7 @@ class FuzzyGridder3D(Gridder3D):
             wz = delta(self.zmin, self.zmax, self.nz) / 2.
 
         # remove normalize flag for C-code
-        flags = utilities.set_bit(self.flags, 2)
+        flags = self.flags | GridderFlags.NO_NORMALIZATION
         cxrayutilities.fuzzygridder3d(x, y, z, data, self.nx, self.ny, self.nz,
                                       self.xmin, self.xmax,
                                       self.ymin, self.ymax,
