@@ -14,7 +14,7 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 # Copyright (C) 2009-2010 Eugen Wintersberger <eugen.wintersberger@desy.de>
-# Copyright (C) 2009-2021 Dominik Kriegner <dominik.kriegner@gmail.com>
+# Copyright (c) 2009-2023 Dominik Kriegner <dominik.kriegner@gmail.com>
 # Copyright (C) 2019 Daniel Schick <schick.daniel@gmail.com>
 
 """
@@ -55,8 +55,10 @@ SPEC_datetime = re.compile(r"^#D")
 SPEC_exptime = re.compile(r"^#T")
 SPEC_nofcols = re.compile(r"^#N")
 SPEC_colnames = re.compile(r"^#L")
-SPEC_MCAFormat = re.compile(r"^#@MCA")
+SPEC_MCAFormat = re.compile(r"^#@MCA ")
 SPEC_MCAChannels = re.compile(r"^#@CHANN")
+SPEC_MCAChannelNames = re.compile(r"^#@DET_\d+")
+SPEC_MCAline = re.compile(r"^@A")
 SPEC_headerline = re.compile(r"^#")
 SPEC_scanbroken = re.compile(r"#C[a-zA-Z0-9: .]*Scan aborted")
 SPEC_scanresumed = re.compile(r"#C[a-zA-Z0-9: .]*Scan resumed")
@@ -66,7 +68,7 @@ SPEC_errorbm20 = re.compile(r"^MI:")
 scan_status_flags = ["OK", "NODATA", "ABORTED", "CORRUPTED"]
 
 
-class SPECScan(object):
+class SPECScan:
     """
     Represents a single SPEC scan. This class is usually not called by the
     user directly but used via the SPECFile class.
@@ -111,6 +113,7 @@ class SPECScan(object):
         self.command = command  # command used to record the data
         self.date = date  # date the command has been sent
         self.time = time  # time the command has been sent
+        self.itime = itime  # integration time of the scan
         self.colnames = colnames  # list with column names
         self.hoffset = hoffset  # file offset where the header data starts
         self.doffset = doffset  # file offset where the data section starts
@@ -158,8 +161,10 @@ class SPECScan(object):
         # some additional attributes for the MCA data
         # False if scan contains no MCA data, True otherwise
         self.has_mca = False
+        self.has_sardana_mca = False
         self.mca_column_format = 0  # number of columns used to save MCA data
         self.mca_channels = 0  # number of channels stored from the MCA
+        self.mca_channel_names = ['MCA']  # name of MCAs
         self.mca_nof_lines = 0  # number of lines used to store MCA data
         self.mca_start_channel = 0  # first channel of the MCA that is stored
         self.mca_stop_channel = 0  # last channel of the MCA that is stored
@@ -182,7 +187,7 @@ class SPECScan(object):
                     cnt += 1
 
     def SetMCAParams(self, mca_column_format, mca_channels,
-                     mca_start, mca_stop):
+                     mca_start, mca_stop, mca_channel_names, has_sardana_mca):
         """
         Set the parameters used to save the MCA data to the file. This method
         calculates the number of lines used to store the MCA data from the
@@ -198,13 +203,20 @@ class SPECScan(object):
             first channel that is stored
         mca_stop :          int
             last channel that is stored
+        mca_channel_names :          list(str)
+            names of mca channels
+        has_sardana_mca :          bool
+            True for Sardana MCA, False for SPEC MCA
         """
         self.has_mca = True
+        self.has_sardana_mca = has_sardana_mca
         self.mca_column_format = mca_column_format
         self.mca_channels = mca_channels
         self.mca_start_channel = mca_start
         self.mca_stop_channel = mca_stop
-
+        if mca_channel_names != []:
+            self.mca_channel_names = mca_channel_names
+        self.mca_nb = len(self.mca_channel_names)
         # calculate the number of lines per data point for the mca
         self.mca_nof_lines = int(mca_channels / mca_column_format)
         if mca_channels % mca_column_format != 0:
@@ -212,6 +224,8 @@ class SPECScan(object):
             self.mca_nof_lines = self.mca_nof_lines + 1
 
         if config.VERBOSITY >= config.DEBUG:
+            print("XU.io.SPECScan.SetMCAParams: channel names: %s"
+                  % self.mca_channel_names)
             print("XU.io.SPECScan.SetMCAParams: number of channels: %d"
                   % self.mca_channels)
             print("XU.io.SPECScan.SetMCAParams: number of columns: %d"
@@ -268,21 +282,29 @@ class SPECScan(object):
             self.fid.seek(self.doffset, 0)
 
             # create dictionary to hold the data
-            if self.has_mca:
-                type_desc = {"names": self.colnames + ["MCA"],
-                             "formats": len(self.colnames) * [numpy.float32] +
-                             [(numpy.uint32, self.mca_channels)]}
+            if self.has_mca and self.has_sardana_mca:
+                type_desc = {"names": self.colnames + self.mca_channel_names,
+                             "formats": len(self.colnames) * [numpy.float64] +
+                             len(self.mca_channel_names)
+                             * [(numpy.float64, self.mca_channels)]}
+            elif self.has_mca and not self.has_sardana_mca:
+                type_desc = {"names": self.colnames + self.mca_channel_names,
+                             "formats": len(self.colnames) * [numpy.float64] +
+                             len(self.mca_channel_names)
+                             * [(numpy.uint32, self.mca_channels)]}
             else:
                 type_desc = {"names": self.colnames,
                              "formats": len(self.colnames) * [numpy.float32]}
 
             if config.VERBOSITY >= config.DEBUG:
-                print("xu.io.SPECScan.ReadData: type descriptor: %s"
-                      % (repr(type_desc)))
+                print("xu.io.SPECScan.ReadData: type descriptor: "
+                      f"{repr(type_desc)}")
 
             record_list = []  # from this list the record array while be built
-
+            scalars_list = []
+            mca_tmp_list = []
             mca_counter = 0
+            mca_list_counter = 0
             scan_aborted_flag = False
 
             for line in self.fid:
@@ -300,69 +322,75 @@ class SPECScan(object):
                         scan_aborted_flag = True
                         self.scan_status = "ABORTED"
                         if config.VERBOSITY >= config.INFO_ALL:
-                            print("XU.io.SPECScan.ReadData: %s aborted"
-                                  % self.name)
+                            print(f"XU.io.SPECScan.ReadData: {self.name} "
+                                  "aborted")
                         continue
-                    elif SPEC_scanresumed.match(line):
+                    if SPEC_scanresumed.match(line):
                         self.scan_status = "OK"
                         scan_aborted_flag = False
                         if config.VERBOSITY >= config.INFO_ALL:
-                            print("XU.io.SPECScan.ReadData: %s resumed"
-                                  % self.name)
+                            print(f"XU.io.SPECScan.ReadData: {self.name} "
+                                  "resumed")
                         continue
-                    elif SPEC_commentline.match(line):
+                    if SPEC_commentline.match(line):
                         continue
-                    elif SPEC_errorbm20.match(line):
+                    if SPEC_errorbm20.match(line):
                         print(line)
                         continue
-                    else:
-                        break
+                    break
 
                 if SPEC_headerline.match(line) or \
                    SPEC_commentline.match(line):
                     if SPEC_scanresumed.match(line):
                         continue
-                    elif SPEC_commentline.match(line):
+                    if SPEC_commentline.match(line):
                         continue
-                    else:
-                        break
+                    break
 
-                if mca_counter == 0:
-                    # the line is a scalar data line
-                    line_list = SPEC_num_value.findall(line)
-                    if config.VERBOSITY >= config.DEBUG:
-                        print("XU.io.SPECScan.ReadData: %s" % line)
-                        print("XU.io.SPECScan.ReadData: read scalar values %s"
-                              % repr(line_list))
-                    # convert strings to numbers
-                    line_list = map(float, line_list)
+                line_list = SPEC_num_value.findall(line)
+                line_list = map(numpy.float64, line_list)
 
-                    # increment the MCA counter if MCA data is stored
-                    if self.has_mca:
-                        mca_counter = mca_counter + 1
-                        # create a temporary list for the mca data
+                if self.has_mca:
+                    if SPEC_MCAline.match(line) \
+                      and ((mca_list_counter == 0) and (mca_counter == 0)):
+                        mca_list_counter += 1
+                        mca_counter += 1
+                        mca_tmp = []
                         mca_tmp_list = []
+                    if (mca_list_counter > 0):
+                        mca_counter += 1
+                        mca_tmp += line_list
+                        if mca_counter > self.mca_nof_lines:
+                            mca_counter = 1
+                            mca_tmp_list.append(mca_tmp.copy())
+                            mca_tmp = []
+                            mca_list_counter += 1
+                            if mca_list_counter > self.mca_nb:
+                                mca_list_counter = 0
                     else:
-                        record_list.append(tuple(line_list))
-                else:
-                    # reading MCA spectrum
-                    mca_tmp_list += map(int, SPEC_int_value.findall(line))
+                        scalars_list = line_list
 
-                    # increment MCA counter
-                    mca_counter = mca_counter + 1
-                    # if mca_counter exceeds the number of lines used to store
-                    # MCA data: append everything to the record list
-                    if mca_counter > self.mca_nof_lines:
-                        record_list.append(tuple(list(line_list) +
-                                                 [mca_tmp_list]))
+                    # check if the data should be written to the records
+                    if (scalars_list != []) \
+                            and (mca_tmp_list != []) \
+                            and (mca_list_counter == 0):
+                        record_list.append(tuple(list(scalars_list)
+                                                 + mca_tmp_list))
+                        scalars_list = []
+                        mca_tmp_list = []
                         mca_counter = 0
 
+                else:
+                    record_list.append(tuple(line_list))
+                    continue
+
             # convert the data to numpy arrays
             ncol = len(record_list[0])
             if config.VERBOSITY >= config.INFO_LOW:
                 print("XU.io.SPECScan.ReadData: %s: %d %d %d"
                       % (self.name, len(record_list), ncol,
                          len(type_desc["names"])))
+
             if ncol == len(type_desc["names"]):
                 try:
                     self.data = numpy.rec.fromrecords(record_list,
@@ -422,7 +450,7 @@ class SPECScan(object):
             try:
                 ydata = self.data[yname]
             except ValueError:
-                raise InputError("no column with name %s exists!" % yname)
+                raise InputError(f"no column with name {yname} exists!")
                 continue
             if logy:
                 plt.semilogy(xdata, ydata, ystyle)
@@ -431,7 +459,7 @@ class SPECScan(object):
 
             leglist.append(yname)
 
-        plt.xlabel("%s" % xname)
+        plt.xlabel(f"{xname}")
         plt.legend(leglist)
         plt.title("scan %i %s\n%s %s"
                   % (self.nr, self.command, self.date, self.time))
@@ -439,7 +467,7 @@ class SPECScan(object):
         lim = plt.axis()
         plt.axis([xdata.min(), xdata.max(), lim[2], lim[3]])
 
-    def Save2HDF5(self, h5f, group="/", title="", optattrs={}, comp=True):
+    def Save2HDF5(self, h5f, group="/", title="", optattrs=None, comp=True):
         """
         Save a SPEC scan to an HDF5 file. The method creates a group with the
         name of the scan and stores the data there as a table object with name
@@ -464,14 +492,14 @@ class SPECScan(object):
         comp :	 bool, optional
             activate compression - true by default
         """
-
+        if optattrs is None:
+            optattrs = {}
         with xu_h5open(h5f, 'a') as h5:
             # check if data object has been already written
             if self.data is None:
                 raise InputError("XU.io.SPECScan.Save2HDF5: No data has been"
                                  "read so far - call ReadData method of the "
                                  "scan")
-                return None
 
             # parse keyword arguments:
             if isinstance(group, str):
@@ -493,7 +521,7 @@ class SPECScan(object):
             # if the group already exists the name must be changed and
             # another will be made to create the group.
             while group_title in rootgroup:
-                group_title = raw_grp_title + "_%i" % (copy_count)
+                group_title = raw_grp_title + f"_{copy_count}"
                 copy_count = copy_count + 1
             g = rootgroup.create_group(group_title)
 
@@ -511,8 +539,8 @@ class SPECScan(object):
             g.attrs['scan_status'] = self.scan_status
 
             # write the initial motor positions as attributes
-            for k in self.init_motor_pos:
-                g.attrs[k] = float(self.init_motor_pos[k])
+            for key, val in self.init_motor_pos.items():
+                g.attrs[key] = float(val)
 
             # if scan contains MCA data write also MCA parameters
             g.attrs['has_mca'] = self.has_mca
@@ -548,7 +576,7 @@ class SPECScan(object):
         """
         if not self.header:
             self.ReadData()
-        re_key = re.compile(r'^#%s (.*)' % key)
+        re_key = re.compile(f'^#{key} (.*)')
         ret = []
         for line in self.header:
             m = re_key.match(line)
@@ -556,12 +584,11 @@ class SPECScan(object):
                 if firstonly:
                     ret = m.groups()[0]
                     break
-                else:
-                    ret.append(m.groups()[0])
+                ret.append(m.groups()[0])
         return ret
 
 
-class SPECFile(object):
+class SPECFile:
 
     """
     This class represents a single SPEC file. The class provides
@@ -637,23 +664,21 @@ class SPECFile(object):
 
             if s is not None:
                 return s
-            else:
-                raise AttributeError("requested scan-number not found")
-        else:
-            raise AttributeError("SPECFile has no attribute '%s'" % name)
+            raise AttributeError("requested scan-number not found")
+        raise AttributeError(f"SPECFile has no attribute '{name}'")
 
     def __len__(self):
         return self.scan_list.__len__()
 
     def __str__(self):
         ostr = ""
-        for i in range(len(self.scan_list)):
-            ostr = ostr + "%5i" % (i)
-            ostr = ostr + self.scan_list[i].__str__()
+        for i, scan in enumerate(self.scan_list):
+            ostr = ostr + f"{i:5d}"
+            ostr = ostr + str(scan)
 
         return ostr
 
-    def Save2HDF5(self, h5f, comp=True, optattrs={}):
+    def Save2HDF5(self, h5f, comp=True, optattrs=None):
         """
         Save the entire file in an HDF5 file. For that purpose a group is set
         up in the root group of the file with the name of the file without
@@ -667,6 +692,8 @@ class SPECFile(object):
         comp :  bool, optional
             activate compression - true by default
         """
+        if optattrs is None:
+            optattrs = {}
         with xu_h5open(h5f, 'a') as h5:
             groupname = os.path.splitext(os.path.splitext(self.filename)[0])[0]
             try:
@@ -674,7 +701,7 @@ class SPECFile(object):
             except ValueError:
                 g = h5.get(groupname)
 
-            g.attrs['TITLE'] = "Data of SPEC - File %s" % (self.filename)
+            g.attrs['TITLE'] = f"Data of SPEC - File {self.filename}"
             for k in optattrs:
                 g.attrs[k] = optattrs[k]
             for s in self.scan_list:
@@ -712,9 +739,11 @@ class SPECFile(object):
             self.fid.seek(self.last_offset, 0)
             scan_started = False
             scan_has_mca = False
+            scan_has_sardana_mca = False
             # list with the motors from whome the initial
             # position is stored.
             init_motor_values = []
+            mca_channel_names = []
 
             if config.VERBOSITY >= config.DEBUG:
                 print('XU.io.SPECFile: start parsing')
@@ -723,7 +752,7 @@ class SPECFile(object):
                 linelength = len(line)
                 line = line.decode('ascii', 'ignore')
                 if config.VERBOSITY >= config.DEBUG:
-                    print('parsing line: %s' % line)
+                    print(f'parsing line: {line}')
 
                 # remove trailing and leading blanks from the read line
                 line = line.strip()
@@ -755,7 +784,8 @@ class SPECFile(object):
                     # define some necessary variables which could be missing in
                     # the scan header
                     itime = numpy.nan
-                    time = ''
+                    time = ""
+                    date = ""
                     if config.VERBOSITY >= config.INFO_ALL:
                         print("XU.io.SPECFile.Parse: processing scan nr. %d "
                               "..." % scannr)
@@ -832,6 +862,10 @@ class SPECFile(object):
                                          line)[0])
                     scan_has_mca = True
 
+                elif SPEC_MCAChannelNames.match(line) and scan_started:
+                    mca_channel_names.append(line.split(" ")[1])
+                    scan_has_sardana_mca = True
+
                 elif SPEC_MCAChannels.match(line) and scan_started:
                     line_list = SPEC_num_value.findall(line)
                     mca_channels = int(line_list[0])
@@ -855,10 +889,13 @@ class SPECFile(object):
                     # reset control flags
                     scan_started = False
                     scan_has_mca = False
+                    scan_has_sardana_mca = False
                     # reset initial motor positions flag
                     init_motor_values = []
+                    mca_channel_names = []
 
-                elif SPEC_dataline.match(line) and scan_started:
+                elif (SPEC_dataline.match(line) or SPEC_MCAline.match(line)) \
+                        and scan_started:
                     # this is now the real end of the header block. at this
                     # point we know that there is enough information about the
                     # scan
@@ -877,15 +914,18 @@ class SPECFile(object):
                                  scan_status)
                     if scan_has_mca:
                         s.SetMCAParams(mca_col_number, mca_channels, mca_start,
-                                       mca_stop)
+                                       mca_stop, mca_channel_names,
+                                       scan_has_sardana_mca)
 
                     self.scan_list.append(s)
 
                     # reset control flags
                     scan_started = False
                     scan_has_mca = False
+                    scan_has_sardana_mca = False
                     # reset initial motor positions flag
                     init_motor_values = []
+                    mca_channel_names = []
 
                 elif SPEC_scan.match(line) and scan_started:
                     # this should only be the case when there are two
@@ -902,8 +942,10 @@ class SPECFile(object):
                     # reset control flags
                     scan_started = False
                     scan_has_mca = False
+                    scan_has_sardana_mca = False
                     # reset initial motor positions flag
                     init_motor_values = []
+                    mca_channel_names = []
 
                     # start parsing of new scan
                     if config.VERBOSITY >= config.DEBUG:
@@ -914,6 +956,7 @@ class SPECFile(object):
                     scancmd = "".join(" " + x + " " for x in line_list[2:])
                     scan_started = True
                     scan_has_mca = False
+                    scan_has_sardana_mca = False
                     scan_header_offset = self.last_offset
                     scan_status = "OK"
                     self.init_motor_names_sh = []
@@ -927,7 +970,7 @@ class SPECFile(object):
             self.last_offset = self.scan_list[-1].doffset
 
 
-class SPECCmdLine(object):
+class SPECCmdLine:
 
     def __init__(self, n, prompt, cmdl, out=""):
         self.linenumber = n
@@ -940,7 +983,7 @@ class SPECCmdLine(object):
         return ostr
 
 
-class SPECLog(object):
+class SPECLog:
     """
     class to parse a SPEC log file to find the command history
     """
@@ -1037,7 +1080,8 @@ def geth5_scan(h5f, scans, *args, **kwargs):
 
     Examples
     --------
-    >>> [om, tt], MAP = xu.io.geth5_scan(h5file, 36, 'omega', 'gamma')
+    >>> [om, tt], MAP = geth5_scan("h5file", 36,
+    ... 'omega', 'gamma')  # doctest: +SKIP
     """
 
     with xu_h5open(h5f) as h5:
@@ -1081,7 +1125,7 @@ def geth5_scan(h5f, scans, *args, **kwargs):
                 motname = args[i]
                 natmotname = utilities.makeNaturalName(motname)
                 buf = numpy.ones(scanshape) * \
-                    h5scan.attrs["INIT_MOPO_%s" % natmotname]
+                    h5scan.attrs[f"INIT_MOPO_{natmotname}"]
                 angles[motname] = numpy.concatenate((angles[motname], buf))
 
     # create return values in correct order
@@ -1100,8 +1144,7 @@ def geth5_scan(h5f, scans, *args, **kwargs):
 
     if not args:
         return MAP
-    else:
-        return retval, MAP
+    return retval, MAP
 
 
 def getspec_scan(specf, scans, *args, **kwargs):
@@ -1132,11 +1175,11 @@ def getspec_scan(specf, scans, *args, **kwargs):
 
     Examples
     --------
-    >>> [om, tt, cnt2] = xu.io.getspec_scan(s, 36, 'omega', 'gamma',
-    >>>                                     'Counter2')
+    >>> [om, tt, cnt2] = getspec_scan(s, 36, 'omega', 'gamma',
+    ... 'Counter2')  # doctest: +SKIP
     """
     if not args:
-        return
+        return InputError("no motor or counter names given")
 
     if numpy.iterable(scans):
         scanlist = scans
