@@ -14,7 +14,7 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 # Copyright (C) 2009 Eugen Wintersberger <eugen.wintersberger@desy.de>
-# Copyright (C) 2009-2022 Dominik Kriegner <dominik.kriegner@gmail.com>
+# Copyright (c) 2009-2023 Dominik Kriegner <dominik.kriegner@gmail.com>
 
 import math
 import re
@@ -54,8 +54,8 @@ def VecNorm(v):
         if len(v.shape) >= 2:
             return numpy.linalg.norm(v, axis=-1)
     if len(v) != 3:
-        raise ValueError("Vector must be of length 3, but has length %d!"
-                         % len(v))
+        raise ValueError(
+            f"Vector must be of length 3, but has length {len(v)}!")
     return math.sqrt(v[0]**2 + v[1]**2 + v[2]**2)
 
 
@@ -77,8 +77,7 @@ def VecUnit(v):
     vtmp = _checkvec(v)
     if len(vtmp.shape) == 1:
         return vtmp / VecNorm(vtmp)
-    else:
-        return vtmp / VecNorm(vtmp)[..., numpy.newaxis]
+    return vtmp / VecNorm(vtmp)[..., numpy.newaxis]
 
 
 def VecDot(v1, v2):
@@ -224,7 +223,7 @@ def getVector(string):
     if len(string) != 2:
         raise InputError("wrong length of string for conversion given")
     if not circleSyntax.search(string):
-        raise InputError("getVector: incorrect string syntax (%s)" % string)
+        raise InputError(f"getVector: incorrect string syntax ({string})")
 
     if string[0] == 'x':
         v = [1., 0, 0]
@@ -324,7 +323,7 @@ def getSyntax(vec):
     return string
 
 
-class Transform(object):
+class Transform:
 
     def __init__(self, matrix):
         self.matrix = matrix
@@ -381,6 +380,8 @@ class Transform(object):
         elif rank == 4:
             # cp_ijkl = m_in * m_jo * m_kp * m_lq * args_nopq
             out = numpy.einsum('in, jo, kp, lq,...nopq', m, m, m, m, args)
+        else:
+            raise ValueError("rank must be either 1, 2, or 4")
 
         return out
 
@@ -637,7 +638,7 @@ def rotarb(vec, axis, ang, deg=True):
 
     Examples
     --------
-    >>> rotarb([1, 0, 0],[0, 0, 1], 90)
-    array([  6.12323400e-17,   1.00000000e+00,   0.00000000e+00])
+    >>> rotarb([1, 0, 0], [0, 0, 1], 90)
+    array([6.123234e-17, 1.000000e+00, 0.000000e+00])
     """
     return ArbRotation(axis, ang, deg)(vec)
