@@ -32,9 +32,8 @@ class TestMaterialsTransform(unittest.TestCase):
         cls.c11, cls.c12, cls.c44 = numpy.random.rand(3) * 1e10
         cls.p1mat = xu.materials.Crystal(
             'P1', xu.materials.SGLattice(1, cls.a, cls.b, cls.c,
-                                         cls.alpha, cls.beta, cls.gamma), 
-                                         xu.materials.CubicElasticTensor(
-                                         cls.c11, cls.c12, cls.c44))
+                                         cls.alpha, cls.beta, cls.gamma),
+            xu.materials.CubicElasticTensor(cls.c11, cls.c12, cls.c44))
 
     def test_q2hkl_hkl2q(self):
         for i in range(3):
@@ -130,25 +129,25 @@ class TestMaterialsTransform(unittest.TestCase):
             self.assertFalse(mat.lattice.isequivalent(hkl1, hkl2s[1]))
 
     def test_Strain(self):
-        strain = numpy.zeros((3,3), dtype=numpy.double)
-        strain[0,0:3] = numpy.random.rand(3)
-        strain[1,1:3] = numpy.random.rand(2)
-        strain[2,2] = numpy.random.rand(1)
-        strain[0:3,0] = strain[0,0:3]
-        strain[1:3,1] = strain[1,1:3]
+        strain = numpy.zeros((3, 3), dtype=numpy.double)
+        strain[0, 0:3] = numpy.random.rand(3)
+        strain[1, 1:3] = numpy.random.rand(2)
+        strain[2, 2] = numpy.random.rand(1)[0]
+        strain[0:3, 0] = strain[0, 0:3]
+        strain[1:3, 1] = strain[1, 1:3]
 
         stress = self.p1mat.GetStress(strain)
         strain_rev = self.p1mat.GetStrain(stress)
         numpy.testing.assert_almost_equal(strain, strain_rev)
 
     def test_Stress(self):
-        stress = numpy.zeros((3,3), dtype=numpy.double)
-        stress[0,0:3] = numpy.random.rand(3)
-        stress[1,1:3] = numpy.random.rand(2)
-        stress[2,2] = numpy.random.rand(1)
-        stress[0:3,0] = stress[0,0:3]
-        stress[1:3,1] = stress[1,1:3]
-        
+        stress = numpy.zeros((3, 3), dtype=numpy.double)
+        stress[0, 0:3] = numpy.random.rand(3)
+        stress[1, 1:3] = numpy.random.rand(2)
+        stress[2, 2] = numpy.random.rand(1)[0]
+        stress[0:3, 0] = stress[0, 0:3]
+        stress[1:3, 1] = stress[1, 1:3]
+
         strain = self.p1mat.GetStrain(stress)
         stress_rev = self.p1mat.GetStress(strain)
         numpy.testing.assert_almost_equal(stress, stress_rev)
